from setuptools import setup

setup(
    name='DXR',
    version='0.1.0',
    packages=['Dxr_mqtt', 'Dxr_log'],
    install_requires=['paho-mqtt'],
    author='luzhipeng',
    author_email='402087139@qq.com',
    license='MIT',
    url='http://pycn.me'
)
